@@ -1,5 +1,8 @@
 from .base import AuthenticationBase
-from urllib.parse import quote_plus
+try:
+    from urllib.parse import quote_plus
+except ImportError:
+    from urllib import quote_plus
 
 
 class Logout(AuthenticationBase):
@@ -10,9 +13,6 @@ class Logout(AuthenticationBase):
         domain (str): Your auth0 domain (e.g: username.auth0.com)
     """
 
-    def __init__(self, domain):
-        self.domain = domain
-
     def logout(self, client_id, return_to, federated=False):
         """Logout
 
@@ -21,7 +21,7 @@ class Logout(AuthenticationBase):
         The URL should be included in any the appropriate Allowed Logout URLs list:
 
         Args:
-            client_id (str): The client_id of your client.
+            client_id (str): The client_id of your application.
 
             returnTo (str): URL to redirect the user after the logout.
 
@@ -31,10 +31,13 @@ class Logout(AuthenticationBase):
 
         if federated is True:
             return self.get(
-                'https://%s/v2/logout?federated&client_id=%s&returnTo=%s' % (self.domain, client_id, return_to),
+                'https://{}/v2/logout?federated&client_id={}&returnTo={}'.format(
+                    self.domain, client_id, return_to),
                 headers={'Content-Type': 'application/json'}
             )
         return self.get(
-            'https://%s/v2/logout?client_id=%s&returnTo=%s' % (self.domain, client_id, return_to),
+            'https://{}/v2/logout?client_id={}&returnTo={}'.format(self.domain,
+                                                                   client_id,
+                                                                   return_to),
             headers={'Content-Type': 'application/json'}
         )
